aboutsummaryrefslogtreecommitdiffstats
path: root/mail/em-folder-tree-model.h
diff options
context:
space:
mode:
Diffstat (limited to 'mail/em-folder-tree-model.h')
-rw-r--r--mail/em-folder-tree-model.h14
1 files changed, 11 insertions, 3 deletions
diff --git a/mail/em-folder-tree-model.h b/mail/em-folder-tree-model.h
index fb0f54a9f0..2dbe7a2a5b 100644
--- a/mail/em-folder-tree-model.h
+++ b/mail/em-folder-tree-model.h
@@ -29,6 +29,8 @@
#include <camel/camel-store.h>
+#include <e-util/e-account-list.h>
+
#ifdef __cplusplus
extern "C" {
#pragma }
@@ -65,6 +67,7 @@ struct _EMFolderTreeModelStoreInfo {
CamelStore *store;
GtkTreeRowReference *row;
GHashTable *path_hash; /* maps CamelFolderInfo::path's to GtkTreeRowReferences */
+ EAccount *account;
char *display_name;
@@ -80,9 +83,14 @@ struct _EMFolderTreeModel {
char *filename; /* state filename */
- GHashTable *store_hash; /* maps CamelStore's to store-info's */
- GHashTable *uri_hash; /* maps URI's to GtkTreeRowReferences */
- GHashTable *expanded; /* saved expanded state from previous session */
+ GHashTable *store_hash; /* maps CamelStore's to store-info's */
+ GHashTable *uri_hash; /* maps URI's to GtkTreeRowReferences */
+ GHashTable *expanded; /* saved expanded state from previous session */
+
+ EAccountList *accounts;
+ GHashTable *account_hash; /* maps accounts to store-info's */
+ gulong account_changed_id;
+ gulong account_removed_id;
};
struct _EMFolderTreeModelClass {